---
layout: ""
page_title: "Resource: multispace_run"
description: |-
  A `multispace_run` manages the initialization and destruction of a Terraform workspace. This will queue and run an `apply` once (only if no other applies have been run) and on destroy will queue and run a `destroy` run.
---

# Resource: Resource

A `multispace_run` manages the initialization and destruction of a
Terraform workspace. This will queue and run an `apply` once (only if no
other applies have been run) and on destroy will queue and run a `destroy`
run.

The workspace must be created prior to the execution fo this resource,
but it can be created dynamically at Terraform apply-time using the
[tfe provider](https://registry.terraform.io/providers/hashicorp/tfe/latest).

~> **Warning!** This will _auto-apply_ a create on creation and a destroy
on destruction. You should be very careful about what is allowed to trigger
this resource and when.

## Example Usage: Cascading Workspaces

```hcl
resource "multispace_run" "root" {
  # Use string workspace names here and not data sources so that
  # you can define the multispace runs before the workspace even exists.
  workspace = "tfc"
}

resource "multispace_run" "physical" {
  organization = "my-org"
  workspace    = "k8s-physical"
  depends_on   = [multispace_run.root]
}

resource "multispace_run" "core" {
  organization = "my-org"
  workspace    = "k8s-core"
  depends_on   = [multispace_run.physical]
}

resource "multispace_run" "dns" {
  organization = "my-org"
  workspace    = "dns"
  depends_on   = [multispace_run.root]
}

resource "multispace_run" "ingress" {
  organization = "my-org"
  workspace    = "ingress"
  depends_on   = [multispace_run.core, multispace_run.dns]
}
```

<!-- schema generated by tfplugindocs -->
## Schema

### Required

- **organization** (String) The name of the Terraform Cloud organization that owns the workspace.
- **workspace** (String) The name of the Terraform Cloud workspace to execute.

### Optional

- **id** (String) The ID of this resource.
